Module: RJSV::CLI::Arguments

Defined in:
lib/rjsv/cli/arguments.rb

Overview

Module for all arguments to the CLI application. The argument initializes the OptionParser, which defines the arguments in detail. It is also nested with a function that adds all arguments from modules.

Class Method Summary collapse

Class Method Details

.active_plugin?Boolean

It finds out if the plugin is written in the argument.

Returns:

  • (Boolean)


72
73
74
75
76
# File 'lib/rjsv/cli/arguments.rb', line 72

def self.active_plugin?
  unless ARGV.empty?
    return ARGV[0].index(/^-/) == nil
  end
end

.optionsObject

Options is a get method and gets all options from arguments.



65
66
67
# File 'lib/rjsv/cli/arguments.rb', line 65

def self.options
  @options
end