Module: RJSV
- Defined in:
- lib/rjsv.rb,
lib/rjsv/watch.rb,
lib/rjsv/plugin.rb,
lib/rjsv/version.rb,
lib/rjsv/constants.rb,
lib/rjsv/translate.rb,
lib/rjsv/cli/states.rb,
lib/rjsv/core/event.rb,
lib/rjsv/core/files.rb,
lib/rjsv/cli/plugins.rb,
lib/rjsv/cli/signals.rb,
lib/rjsv/cli/arguments.rb,
lib/rjsv/core/constants.rb
Overview
This is the main initialization module of all modules that are needed for the functionality of this RubyJS-Vite transpiler. The methods that shape the direction of the application are also written here.
Defined Under Namespace
Modules: CLI, Constants, Core, Translate, Watch Classes: Plugin
Constant Summary collapse
- VERSION =
'2.0.2'
Class Method Summary collapse
-
.main ⇒ Object
This is the main function to run the desired block function scenarios.
Class Method Details
.main ⇒ Object
This is the main function to run the desired block function scenarios. In order to arm itself regarding plugins and directly Arguments, this method checks the accessibility of the plugin by checking if it is active or attached in the argument given by the confirmed command from the terminal.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/rjsv.rb', line 41 def main() unless CLI::Arguments.active_plugin? if @options_cli[:translate] files_rb = Core::Files.find_all(@options_cli[:source]) files_rb.each do |path| CLI::States.translate_state(path, @options_cli) end end CLI::States.watch_state(@options_cli) end end |